# Generated by roxygen2: do not edit by hand

S3method(combine_tech_reps,data.frame)
S3method(combine_tech_reps,pepdiff_data)
S3method(compare,data.frame)
S3method(compare,pepdiff_data)
S3method(get_comparison,pepdiff_results)
S3method(get_peptide,pepdiff_results)
S3method(plot,pepdiff_data)
S3method(plot,pepdiff_results)
S3method(print,pepdiff_data)
S3method(print,pepdiff_results)
S3method(significant,pepdiff_results)
S3method(subset,pepdiff_data)
S3method(summary,pepdiff_data)
S3method(summary,pepdiff_results)
export("%>%")
export(assess_missing)
export(classify_bf_evidence)
export(combine_tech_reps)
export(compare)
export(compare_calls)
export(compare_many)
export(estimate_result_clusters)
export(fc_qqplot)
export(get_bootstrap_percentile)
export(get_comparison)
export(get_kruskal_percentile)
export(get_peptide)
export(get_rp_percentile)
export(get_wilcoxon_percentile)
export(import_data)
export(kmeans_by_selected_cols)
export(long_results)
export(missing_peptides_plot)
export(norm_qqplot)
export(p_value_hist)
export(plot_bf_distribution)
export(plot_distributions_simple)
export(plot_fc)
export(plot_fc_distribution_new)
export(plot_fit_diagnostics)
export(plot_heatmap)
export(plot_kmeans)
export(plot_missingness_simple)
export(plot_pca)
export(plot_pca_simple)
export(plot_pvalue_histogram)
export(plot_quant_distributions)
export(plot_result)
export(plot_volcano_bf)
export(plot_volcano_new)
export(read_pepdiff)
export(significant)
export(test_bayes_t)
export(test_bootstrap_t)
export(test_rankprod)
export(test_wilcoxon)
export(times_measured)
export(times_measured_plot)
export(volcano_plot)
importFrom(magrittr,"%>%")
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(stats,complete.cases)
importFrom(stats,kmeans)
